# Welcome to ordotools

> Traditional Catholic Ordo and Calendar

### 🏠 [Homepage](https://ordo.media/calendar)

## Install

```sh
pip install ordotools
```

## Author

👤 **Fr. Gregory R. Barnes**

* Github: [@corei8](https://github.com/corei8)

## Show your support

Give a ⭐️ if this project helped you!
